OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "無法寫入「config」 目錄！",
    "This can usually be fixed by giving the web server write access to the config directory." : "開通網頁伺服器寫入 config 目錄的存取權，通常可以解決這個問題。",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但如果您比較希望保留 config.php 的唯讀狀態，請在該組態設定檔中將「config_is_read_only」設定為 true。",
    "See %s" : "請見 %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "應用程式 %1$s 不存在，或有與此伺服器不相容的版本。請檢查應用程式目錄。",
    "Sample configuration detected" : "偵測到正在使用範例組態設定",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接複製了範例組態設定來使用。這可能讓您的安裝無法運作，而且為不被支援的作法。請在閱讀文件後，重新對 config.php 做出適當修改",
    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
    "%s email verification" : "%s 電子郵件驗證",
    "Email verification" : "電子郵件驗證",
    "Click the following button to confirm your email." : "點擊以下按鈕以確認您的電子郵件。",
    "Click the following link to confirm your email." : "點擊以下連結以確認您的電子郵件。",
    "Confirm your email" : "確認您的電子郵件",
    "Other activities" : "其他活動",
    "%1$s and %2$s" : "%1$s 和 %2$s",
    "%1$s, %2$s and %3$s" : "%1$s、%2$s 和 %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s、%2$s、%3$s 和 %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s、%2$s、%3$s、%4$s 和 %5$s",
    "Education bundle" : "教育組合包",
    "Enterprise bundle" : "企業套組",
    "Groupware bundle" : "協作應用套組",
    "Hub bundle" : "Hub 套組",
    "Public sector bundle" : "公部門組合包",
    "Social sharing bundle" : "社交分享套組",
    "PHP %s or higher is required." : "需要 PHP %s 或更高版本。",
    "PHP with a version lower than %s is required." : "需要 PHP 版本低於 %s。",
    "%sbit or higher PHP required." : "需要 %s 位元或更高的 PHP 版本。",
    "The following architectures are supported: %s" : "支援下列架構：%s",
    "The following databases are supported: %s" : "支援下列資料庫：%s",
    "The command line tool %s could not be found" : "找不到命令列工具命令 %s",
    "The library %s is not available." : "函式庫 %s 無法使用。",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "需要使用高於 %2$s 版的 %1$s 函式庫，目前可用的版本是 %3$s。",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "需要使用低於 %2$s 版的 %1$s 函式庫，目前可用的版本是 %3$s。",
    "The following platforms are supported: %s" : "支援下列平台：%s",
    "Server version %s or higher is required." : "需要伺服器版本 %s 或更高。",
    "Server version %s or lower is required." : "需要伺服器版本 %s 或更低。",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登入帳號必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
    "Your current IP address doesn't allow you to perform admin actions" : "您目前的 IP 位置不允許您執行管理動作",
    "Logged in account must be an admin or sub admin" : "登入的帳號必須要是管理員或是子管理員",
    "Logged in account must be an admin" : "登入的帳號必須有管理員權限",
    "Wiping of device %s has started" : "已開始抹除裝置 %s",
    "Wiping of device »%s« has started" : "已開始抹除裝置「%s」",
    "»%s« started remote wipe" : "「%s」開始遠端抹除",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "裝置或應用程式「%s」已開始遠端抹除的流程。完成後您將會收到另一封通知信",
    "Wiping of device %s has finished" : "裝置 %s 抹除完成",
    "Wiping of device »%s« has finished" : "裝置「%s」抹除完成",
    "»%s« finished remote wipe" : "裝置「%s」完成遠端抹除",
    "Device or application »%s« has finished the remote wipe process." : "裝置或應用程式「%s」已完成遠端抹除。",
    "Remote wipe started" : "遠端抹除已開始",
    "A remote wipe was started on device %s" : "遠端抹除已在裝置 %s 開始",
    "Remote wipe finished" : "遠端抹除已完成",
    "The remote wipe on %s has finished" : "%s 的遠端抹除已完成",
    "Authentication" : "認證",
    "Unknown filetype" : "未知的檔案類型",
    "Invalid image" : "無效的圖片",
    "Avatar image is not square" : "頭像不是正方形",
    "Files" : "檔案",
    "View profile" : "檢視個人檔案",
    "same time" : "相同時間",
    "_%nh_::_%nh_" : ["%n小時"],
    "_%nm_::_%nm_" : ["%n分鐘"],
    "%s ahead" : "提早 %s",
    "%s behind" : "落後 %s",
    "Local time: %s" : "本機時間：%s",
    "today" : "今天",
    "tomorrow" : "明天",
    "yesterday" : "昨天",
    "_in %n day_::_in %n days_" : ["在 %n 天內"],
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "next month" : "下個月",
    "last month" : "上個月",
    "_in %n month_::_in %n months_" : ["在 %n 個月內"],
    "_%n month ago_::_%n months ago_" : ["%n 個月前"],
    "next year" : "明年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["在 %n 年內"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n 小時後"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
    "_in %n minute_::_in %n minutes_" : ["在 %n 分鐘內"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
    "in a few seconds" : "幾秒內",
    "seconds ago" : "幾秒前",
    "Empty file" : "空白檔案",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID 為 %s 的模組不存在。請在應用程式設定中啟用，或是聯絡系統管理員。",
    "No file conversion providers available" : "沒有可用的檔案轉換提供者",
    "File is too large to convert" : "檔案太大，無法轉換",
    "Destination does not match conversion extension" : "目的地不符合轉換副檔名",
    "Could not convert file" : "無法轉換檔案",
    "Destination does not exist" : "目的地不存在",
    "Destination is not creatable" : "無法建立目的地",
    "Dot files are not allowed" : "不允許小數點開頭的檔案",
    "%1$s (renamed)" : "%1$s（已重新命名）",
    "renamed file" : "已重新命名檔案",
    "\"%1$s\" is a forbidden file or folder name." : "「%1$s」是禁止的檔案或資料夾名稱。",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "「%1$s」是禁止的檔案或資料夾名稱前綴。",
    "\"%1$s\" is not allowed inside a file or folder name." : "「%1$s」不允許出現在檔案或資料夾名稱中。",
    "\"%1$s\" is a forbidden file type." : "「%1$s」是禁止的檔案類型。",
    "Filenames must not end with \"%1$s\"." : "檔案名稱不能以「%1$s」結尾。",
    "Invalid parent path" : "無效的上層路徑",
    "File already exists" : "檔案已存在",
    "Invalid path" : "無效的路徑",
    "Failed to create file from template" : "無法從範本建立檔案",
    "Templates" : "範本",
    "Storage %s cannot be moved" : "無法移動儲存空間 %s",
    "Moving a share (%s) into a shared folder is not allowed" : "不允許將分享 (%s) 移動到共享資料夾中",
    "Moving a storage (%s) into a shared folder is not allowed" : "不允許將儲存空間(%s) 移動到共享資料夾中",
    "Moving a share (%s) into another share (%s) is not allowed" : "不允許將分享 (%s) 移動到其他分享 (%s) 中",
    "Moving a share (%s) into another storage (%s) is not allowed" : "不允許將分享 (%s) 移動到其他儲存空間 (%s) 中",
    "Moving a storage (%s) into a share (%s) is not allowed" : "不允許將儲存空間 (%s) 移動到分享 (%s) 中",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "不允許將儲存空間 (%s) 移動到其他儲存空間 (%s) 中",
    "Path contains invalid segments" : "路徑包含無效的部份",
    "Filename is a reserved word" : "檔案名稱是保留字",
    "Filename contains at least one invalid character" : "檔案名稱包含了至少一個無效的字元",
    "Filename is too long" : "檔案名稱太長",
    "Empty filename is not allowed" : "不允許空白的檔名",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "由於無法讀取 appinfo 檔案，應用程式「%s」無法安裝。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "由於不相容於目前版本的伺服器，應用程式「%s」無法安裝。",
    "__language_name__" : "正體中文（臺灣）",
    "This is an automatically sent email, please do not reply." : "這是自動寄送的電子郵件，請不要回覆。",
    "Help & privacy" : "說明與隱私",
    "Appearance and accessibility" : "外觀與無障礙存取",
    "Apps" : "應用程式",
    "Personal settings" : "個人設定",
    "Administration settings" : "管理設定",
    "Settings" : "設定",
    "Log out" : "登出",
    "Accounts" : "帳號",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "在 Bluesky 上檢視 %s",
    "Email" : "電子郵件",
    "Mail %s" : "寄送郵件給 %s",
    "Fediverse" : "聯邦宇宙",
    "View %s on the fediverse" : "在聯邦宇宙上檢視 %s",
    "Phone" : "手機",
    "Call %s" : "打給 %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "在 Twitter 上檢視 %s",
    "Website" : "網站",
    "Visit %s" : "造訪 %s",
    "Address" : "地址",
    "Profile picture" : "個人檔案圖片",
    "About" : "關於",
    "Display name" : "顯示名稱",
    "Headline" : "重要經歷",
    "Organization" : "組織",
    "Role" : "職位",
    "Pronouns" : "代名詞",
    "Unknown account" : "未知的帳號",
    "Additional settings" : "其他設定",
    "Enter the database Login and name for %s" : "輸入 %s 的資料庫帳號與名稱",
    "Enter the database Login for %s" : "輸入 %s 的資料庫帳號",
    "Enter the database name for %s" : "輸入 %s 的資料庫名稱",
    "You cannot use dots in the database name %s" : "資料庫名稱 %s 不能包含小數點",
    "MySQL Login and/or password not valid" : "MySQL 帳號或密碼不正確",
    "You need to enter details of an existing account." : "您必須輸入已有的帳號資訊。",
    "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
    "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
    "macOS is not supported and %s will not work properly on this platform." : "不支援 macOS，%s 在此平台上無法正常運作。",
    "For the best results, please consider using a GNU/Linux server instead." : "請考慮改用 GNU/Linux 伺服器以獲得最佳結果。",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 站台似乎是在 32 位元 PHP 環境執行，且似乎設定了 php.ini 中的 open_basedir。這將導致超過 4 GB 的檔案出現問題，因此強烈建議不要這麼做。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP。",
    "Set an admin Login." : "設定管理員帳號。",
    "Set an admin password." : "設定管理員密碼。",
    "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend 介面",
    "Sharing backend %s not found" : "找不到分享後端 %s",
    "Sharing backend for %s not found" : "找不到 %s 的分享後端",
    "%1$s shared %2$s with you" : "%1$s 與您分享了 %2$s",
    "Open %s" : "開啟 %s",
    "%1$s via %2$s" : "%1$s 經由 %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s 與您分享了 %2$s，且想要新增：",
    "%1$s shared %2$s with you and wants to add" : "%1$s 與您分享了 %2$s，且想要新增",
    "%s added a note to a file shared with you" : "%s 在與您分享的檔案新增了註記",
    "Passwords are enforced for link and mail shares" : "連結與郵件分享強制使用密碼",
    "Share recipient is not a valid user" : "分享的接收者不是有效的使用者",
    "Share recipient is not a valid group" : "分享的接收者不是有效的群組",
    "Share recipient should be empty" : "分享的接收者應為空",
    "Share recipient should not be empty" : "分享的接收者不應為空",
    "Share recipient is not a valid circle" : "分享的接收者不是有效的小圈圈",
    "Unknown share type" : "未知的分享類型",
    "Share initiator must be set" : "必須設定分享發起者",
    "Cannot share with yourself" : "無法與您自己分享",
    "Shared path must be set" : "必須設定分享路徑",
    "Shared path must be either a file or a folder" : "分享路徑必須為檔案或資料夾",
    "You cannot share your root folder" : "您無法分享您的根資料夾",
    "You are not allowed to share %s" : "您不被允許分享 %s",
    "Valid permissions are required for sharing" : "分享需要有效的權限",
    "File shares cannot have create or delete permissions" : "檔案分享不能有建立或刪除權限",
    "Cannot increase permissions of %s" : "無法增加 %s 的權能",
    "Shares need at least read permissions" : "分享需要至少讀取的權限",
    "Files cannot be shared with delete permissions" : "無法分享權限允許刪除的檔案",
    "Files cannot be shared with create permissions" : "無法分享權限允許新建的檔案",
    "Expiration date is in the past" : "到期日為過去的日期",
    "Expiration date is enforced" : "有效日期為強制要求",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["無法設定到期日超過未來 %n 天"],
    "Sharing is only allowed with group members" : "僅允許與群組成員分享",
    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳號 %s 分享",
    "Group sharing is now allowed" : "現在允許群組分享",
    "Sharing is only allowed within your own groups" : "僅允許與您自己的群組分享",
    "Path is already shared with this group" : "路徑已與此群組分享",
    "Link sharing is not allowed" : "不允許連結分享",
    "Public upload is not allowed" : "不允許公開上傳",
    "You cannot share a folder that contains other shares" : "您無法分享包含其他分享的資料夾",
    "Sharing is disabled" : "已停用分享",
    "Sharing is disabled for you" : "您已停用分享",
    "Cannot share with the share owner" : "無法與分享擁有者分享",
    "Share does not have a full ID" : "分享並無完整 ID",
    "Cannot change share type" : "無法變更分享類型",
    "Can only update recipient on user shares" : "僅能更新使用者分享的收件者",
    "Cannot enable sending the password by Talk with an empty password" : "若密碼為空，則無法啟用透過 Talk 傳送密碼",
    "Cannot enable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法啟用透過 Talk 傳送密碼",
    "Cannot disable sending the password by Talk without setting a new password" : "若未設定新密碼，則無法停用透過 Talk 傳送密碼",
    "Share provider does not support accepting" : "分享提供者不支援接受",
    "Cannot change target of link share" : "無法變更連結分享的目標",
    "Invalid share recipient" : "無效的分享接收者",
    "Group \"%s\" does not exist" : "群組「%s」不存在",
    "The requested share does not exist anymore" : "請求的分享已不存在",
    "The requested share comes from a disabled user" : "請求的分享來自已停用的使用者",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "未建立使用者，因為已達使用者上限。請檢查您的通知以深入瞭解。",
    "Could not find category \"%s\"" : "找不到分類：「%s」",
    "Input text" : "輸入文字",
    "The input text" : "輸入文字",
    "Cannot generate more than 12 images" : "無法產生超過 12 張影像",
    "Cannot generate less than 1 image" : "無法產生少於 1 張影像",
    "Sunday" : "週日",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sun." : "日",
    "Mon." : "一",
    "Tue." : "二",
    "Wed." : "三",
    "Thu." : "四",
    "Fri." : "五",
    "Sat." : "六",
    "Su" : "日",
    "Mo" : "一",
    "Tu" : "二",
    "We" : "三",
    "Th" : "四",
    "Fr" : "五",
    "Sa" : "六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "1月",
    "Feb." : "2月",
    "Mar." : "3月",
    "Apr." : "4月",
    "May." : "5月",
    "Jun." : "6月",
    "Jul." : "7月",
    "Aug." : "8月",
    "Sep." : "9月",
    "Oct." : "10月",
    "Nov." : "11月",
    "Dec." : "12月",
    "A valid password must be provided" : "須提供有效的密碼",
    "The Login is already being used" : "這個帳號已經有人使用了",
    "Could not create account" : "無法建立帳號",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "帳號僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
    "A valid Login must be provided" : "必須提供有效帳號",
    "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
    "Login must not consist of dots only" : "帳號不能只包含小數點",
    "Username is too long" : "使用者名稱太長了",
    "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
    "Account disabled" : "帳號已停用",
    "Login canceled by app" : "應用程式取消了登入",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "未滿足以下依賴關係，無法安裝應用程式「%1$s」：%2$s",
    "a safe home for all your data" : "您所有資料的安全屋",
    "Application is not enabled" : "應用程式未啟用",
    "Authentication error" : "認證錯誤",
    "Token expired. Please reload page." : "代符過期。請重新載入頁面。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "未安裝資料庫驅動器（sqlite、mysql 或 postgresql）。",
    "Cannot write into \"config\" directory." : "無法寫入「config」目錄。",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "開通網頁伺服器寫入 config 目錄的存取權，通常可以解決這個問題。請見 %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果您比較希望保留 config.php 的唯讀狀態，請在該組態設定檔中將 「config_is_read_only」設定為 true。請見 %s",
    "Cannot create \"data\" directory." : "無法建立「data」目錄。",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "開通網頁伺服器寫入根目錄的存取權，通常可以修正這個問題。請見 %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "開通網頁伺服器可寫入根目錄的存取權，通常可以修正權限問題。請見 %s。",
    "Your data directory is not writable." : "您的 data 目錄無法寫入。",
    "Setting locale to %s failed." : "將地區設定為 %s 時失敗。",
    "Please install one of these locales on your system and restart your web server." : "請在您的系統上安裝這些地區設定中的其中一個，然後重新啟動網頁伺服器。",
    "PHP module %s not installed." : "未安裝 PHP 模組 %s。",
    "Please ask your server administrator to install the module." : "請要求您的伺服器管理員安裝模組。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 設定值「%s」未設定為「%s」。",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "調整 php.ini 中的設定，會讓 Nextcloud 重新執行",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 顯然設定為剪除 inline 的文件嵌入區塊。這會讓多個核心應用程式無法運作。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這可能是快取或加速程式（如 Zend OPcache 或 eAccelerator）所造成。",
    "PHP modules have been installed, but they are still listed as missing?" : "您已安裝指定的 PHP 模組，可是還是顯示為找不到嗎？",
    "Please ask your server administrator to restart the web server." : "請要求您的伺服器管理員重新啟動網頁伺服器。",
    "The required %s config variable is not configured in the config.php file." : "必要的 %s 組態設定變數，未在 config.php 檔案中設定。",
    "Please ask your server administrator to check the Nextcloud configuration." : "請聯絡您的伺服器管理員檢查 Nextcloud 組態設定。",
    "Your data directory is readable by other people." : "您的 data 目錄可被其他使用者讀取。",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
    "Your data directory must be an absolute path." : "您的 data 目錄必須是絕對路徑。",
    "Check the value of \"datadirectory\" in your configuration." : "請檢查您組態設定檔中「datadirectory」的值。",
    "Your data directory is invalid." : "您的 data 目錄無效。",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "請確保資料目錄最上層有一個「%1$s」檔案。其應有內容：「%2$s」",
    "Action \"%s\" not supported or implemented." : "並不支援動作「%s」，或是尚未實作。",
    "Authentication failed, wrong token or provider ID given" : "認證失敗，提供了錯誤的代符或提供者 ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "欠缺參數無法完成請求。缺少的參數：「%s」",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID「%1$s」已被另一個雲端聯邦提供者「%2$s」所使用",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID 為「%s」的雲端聯邦提供者不存在。",
    "Could not obtain lock type %d on \"%s\"." : "無法取得鎖定，類型為 %d ，檔案「%s」。",
    "Storage unauthorized. %s" : "儲存空間未經授權。%s",
    "Storage incomplete configuration. %s" : "儲存空間組態設定不完整。%s",
    "Storage connection error. %s" : "儲存空間連線錯誤。%s",
    "Storage is temporarily not available" : "儲存空間暫時無法使用",
    "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "若要允許執行此檢查，您必須確保您的網路伺服器可以連線到其自身。因此，其必須可以解析並連線到 `trusted_domains` 或 `overwrite.cli.url` 至少其中一個。此失敗可能是因為伺服器端 DNS 不符或連出防火牆規則造成的。",
    "Analyze images" : "分析影像",
    "Ask a question about the given images." : "詢問關於指定影像的問題。",
    "Images" : "圖片",
    "Images to ask a question about" : "要提出問題的影像",
    "Question" : "問題",
    "What to ask about the images." : "要問什麼關於影像的問題。",
    "Generated response" : "已產生的回應",
    "The answer to the question" : "問題的答案",
    "Audio chat" : "語音聊天",
    "Voice chat with the assistant" : "與小幫手使用語音聊天",
    "System prompt" : "系統提示詞",
    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
    "Chat voice message" : "聊天語音訊息",
    "Describe a task that you want the assistant to do or ask a question." : "描述您希望助理執行的任務或提出問題。",
    "Chat history" : "聊天歷史紀錄",
    "The history of chat messages before the current message, starting with a message by the user." : "目前訊息開始之前的聊天歷史紀錄，從使用者的訊息開始。",
    "Input transcript" : "輸入轉錄",
    "Transcription of the audio input" : "語音輸入轉錄",
    "Response voice message" : "回應語音訊息",
    "The generated voice response as part of the conversation" : "產生的語音回應是對話的一部分",
    "Output transcript" : "輸出轉錄",
    "Transcription of the audio output" : "音訊輸出轉錄",
    "Transcribe audio" : "轉錄音訊",
    "Transcribe the things said in an audio" : "轉錄音訊中所說的話",
    "Audio input" : "音訊輸入",
    "The audio to transcribe" : "要轉錄的音訊",
    "Transcription" : "轉錄",
    "The transcribed text" : "已轉錄的文字",
    "Chat by voice with an agent" : "與 agent 語音聊天",
    "Describe a task that you want the agent to do or ask a question." : "描述您希望 agent執行的任務或提出問題。",
    "Confirmation" : "確認",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "是否確認先前要求的動作：0 代表拒絕，1 代表確認。",
    "Conversation token" : "對話權杖",
    "A token representing the conversation." : "代表對話的權杖。",
    "The new conversation token" : "新對話權杖",
    "Send this along with the next interaction." : "將這個與下一次互動一起傳送。",
    "Requested actions by the agent" : "Agent 要求的動作",
    "Actions that the agent would like to carry out in JSON format." : "Agent 希望以 JSON 格式執行的動作。",
    "Chat with an agent" : "與 agent 聊天",
    "Chat message" : "聊天訊息",
    "A chat message to send to the agent." : "要傳送給 agent 的聊天訊息。",
    "The response from the chat model." : "來自聊天模型的回應。",
    "Context write" : "寫作情境",
    "Writes text in a given style based on the provided source material." : "根據提供的來源資料以指定的風格編寫文字",
    "Writing style" : "寫作風格",
    "Demonstrate a writing style that you would like to immitate" : "展現您想模仿的寫作風格",
    "Source material" : "來源資料",
    "The content that would like to be rewritten in the new writing style" : "想要用新的寫作風格重寫的內容",
    "Generated text" : "產生的文字",
    "The generated text with content from the source material in the given style" : "產生的文字包含來自指定樣式的原始素材的內容",
    "Emoji generator" : "表情符號產生程式",
    "Takes text and generates a representative emoji for it." : "取得文字並為其產生代表性表情符號。",
    "The text to generate an emoji for" : "用來產生表情符號的文字",
    "Generated emoji" : "已產生表情符號",
    "The generated emoji based on the input text" : "以輸入文字為基礎產生的表情符號",
    "Optical character recognition" : "光學字元辨識 (OCR)",
    "Extract text from files like images or PDFs" : "從影像或 PDF 等檔案中擷取文字",
    "Input files" : "輸入檔案",
    "The files to extract text from" : "用來擷取文字的檔案",
    "Output texts" : "輸出文字",
    "The texts that were extracted from the files" : "從檔案擷取的文字",
    "Generate image" : "產生影像",
    "Generate an image from a text prompt" : "根據文字提示產生影像",
    "Prompt" : "提示詞",
    "Describe the image you want to generate" : "描述您想要產生的影像",
    "Number of images" : "影像數量",
    "How many images to generate" : "要產生多少影像",
    "Output images" : "輸出影像",
    "The generated images" : "產生的影像",
    "Generate speech" : "產生語音",
    "Generate speech from a transcript" : "從轉錄稿產生語音",
    "Write transcript that you want the assistant to generate speech from" : "寫下您想要小幫手產生語音的來源轉錄稿",
    "Output speech" : "輸出語音",
    "The generated speech" : "產生的語音",
    "Free text to text prompt" : "文字提示的自由文字",
    "Runs an arbitrary prompt through a language model that returns a reply" : "透過回傳回覆的語言模型執行任意提示",
    "Describe a task that you want the assistant to do or ask a question" : "描述您希望助理執行的任務或提出問題",
    "Generated reply" : "已產生的回覆",
    "The generated text from the assistant" : "從助理產生的文字",
    "Change Tone" : "變更語氣",
    "Change the tone of a piece of text." : "變更一段文字的語氣。",
    "Write a text that you want the assistant to rewrite in another tone." : "寫一段您希望小幫手以其他語氣重寫的文字。",
    "Desired tone" : "希望的語氣",
    "In which tone should your text be rewritten?" : "您的文字應該以哪種語氣重寫？",
    "The rewritten text in the desired tone, written by the assistant:" : "小幫手以您希望的語氣重寫後的文字：",
    "Chat" : "聊天",
    "Chat with the assistant" : "與小幫手聊天",
    "The history of chat messages before the current message, starting with a message by the user" : "目前訊息開始之前的聊天歷史紀錄，從使用者的訊息開始",
    "Response message" : "回應訊息",
    "The generated response as part of the conversation" : "作為對話一部份產生的回應",
    "Chat with tools" : "與工具聊天",
    "Chat with the language model with tool calling support." : "與支援呼叫工具的語言模型聊天。",
    "Tool message" : "工具訊息",
    "The result of tool calls in the last interaction" : "上一次互動中工具呼叫的結果",
    "Available tools" : "可用的工具",
    "The available tools in JSON format" : "以 JSON 格式列出可用的工具",
    "The response from the chat model" : "來自聊天模型的回應",
    "Tool calls" : "工具呼叫",
    "Tools call instructions from the model in JSON format" : "來自模型的工具呼叫，以 JSON 格式表示",
    "Formalize text" : "正式化文字",
    "Takes a text and makes it sound more formal" : "取得文字並使其看起來更正式",
    "Write a text that you want the assistant to formalize" : "寫下您希望小幫手協助您正式化的文字",
    "Formalized text" : "正式化文字",
    "The formalized text" : "正式化文字",
    "Generate a headline" : "產生標題",
    "Generates a possible headline for a text." : "為文字產生可能的標題。",
    "Original text" : "原始文字",
    "The original text to generate a headline for" : "用來產生標題的原始文字",
    "The generated headline" : "產生的標題",
    "Proofread" : "校對",
    "Proofreads a text and lists corrections" : "校對文字並列出修正項目",
    "Text" : "文字",
    "The text to proofread" : "要校對的文字",
    "Corrections" : "修正",
    "The corrections that should be made in your text" : "您文字中應進行的修正",
    "Reformulate text" : "重新表述文字",
    "Takes a text and reformulates it" : "取得文字並將其重新表述",
    "Write a text that you want the assistant to reformulate" : "寫下您希望小幫手協助您重新表述的文字",
    "Reformulated text" : "已重新表述的文字",
    "The reformulated text, written by the assistant" : "已重新表述的文字，由小幫手編寫",
    "Simplify text" : "簡化文字",
    "Takes a text and simplifies it" : "取得文字並將其簡化",
    "Write a text that you want the assistant to simplify" : "寫下您希望小幫手協助您簡化的文字",
    "Simplified text" : "簡化後的文字",
    "The simplified text" : "簡化後的文字",
    "Summarize" : "摘要",
    "Summarizes a text" : "總結一段文字",
    "The original text to summarize" : "要總結的原始文字",
    "Summary" : "摘要",
    "The generated summary" : "產生的總結",
    "Extract topics" : "取出主題",
    "Extracts topics from a text and outputs them separated by commas" : "從文字中擷取主題並輸出，然後用逗號分隔",
    "The original text to extract topics from" : "用來擷取主題的原始文字",
    "Topics" : "主題",
    "The list of extracted topics" : "擷取的主題清單",
    "Translate" : "翻譯",
    "Translate text from one language to another" : "從一個語言翻譯成其他語言的文字",
    "Origin text" : "原始文字",
    "The text to translate" : "要翻譯的文字",
    "Origin language" : "原始語言",
    "The language of the origin text" : "原始文字語言",
    "Target language" : "目標語言",
    "The desired language to translate the origin text in" : "要翻譯原始文字成什麼語言",
    "Result" : "結果",
    "The translated text" : "已翻譯的文字",
    "Free prompt" : "自由提示詠唱",
    "Runs an arbitrary prompt through the language model." : "透過語言模型執行任意提示詞詠唱。",
    "Generate headline" : "生成標題",
    "Summarizes text by reducing its length without losing key information." : "寫成摘要，減少文字長度而不丟失關鍵資訊。",
    "Extracts topics from a text and outputs them separated by commas." : "從文字中取出涵蓋的主題並輸出，然後用逗號分隔。",
    "Organisation" : "組織單位",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "不支援 Mac OS X，%s 在此平台上無法正常運作。請自行承擔使用風險！",
    "Login is too long" : "帳號太長了",
    "Cannot write into \"apps\" directory." : "無法寫入「apps」目錄。",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "開通網頁伺服器寫入 apps 目錄的存取權，或是在組態設定檔中停用應用程式商店，通常可以解決這個問題。",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 設定為 <code>%s</code>，而非預期中的 <code>0</code>。",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。"
},
"nplurals=1; plural=0;");
